'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TYPES = exports.SIZES = exports.BASE_CLASS = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _toggle = require('./SwitchType/toggle');

var _single = require('./SwitchType/single');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var BASE_CLASS = exports.BASE_CLASS = 'sui-AtomSwitch';

var SIZES = exports.SIZES = {
  DEFAULT: 'default',
  LARGE: 'large'
};

var TYPES = exports.TYPES = {
  TOGGLE: 'toggle',
  SELECT: 'select',
  SINGLE: 'single'
};

var AtomSwitch = function (_Component) {
  (0, _inherits3.default)(AtomSwitch, _Component);

  function AtomSwitch(props) {
    (0, _classCallCheck3.default)(this, AtomSwitch);

    var _this = (0, _possibleConstructorReturn3.default)(this, (AtomSwitch.__proto__ || (0, _getPrototypeOf2.default)(AtomSwitch)).call(this, props));

    _this.state = {
      toggle: false,
      isFocus: false
    };

    _this.keyBindings = function (event) {
      var isFocus = _this.state.isFocus;

      if (!isFocus || event.defaultPrevented) {
        return;
      }
      if (event.key === 'Enter' || event.key === ' ' || event.key === 'Spacebar') {
        _this.toggleSwitch();
        event.preventDefault();
      }
    };

    _this.toggleSwitch = function () {
      var toggle = _this.state.toggle;
      var onToggle = _this.props.onToggle;

      _this.setState({ toggle: !toggle }, function () {
        return onToggle(!toggle);
      });
    };

    _this.activateToggle = function () {
      _this.setState({ toggle: true });
    };

    _this.deactivateToggle = function () {
      _this.setState({ toggle: false });
    };

    _this.executeIfEnabled = function (func) {
      return function () {
        var disabled = _this.props.disabled;

        !disabled && func();
      };
    };

    _this.focusSwitch = function () {
      _this.setState({ isFocus: true });
    };

    _this.focusOutSwitch = function () {
      _this.setState({ isFocus: false });
    };

    _this.executeIfEnabledFocusSwitch = _this.executeIfEnabled(_this.focusSwitch);
    _this.executeIfEnabledFocusOutSwitch = _this.executeIfEnabled(_this.focusOutSwitch);
    _this.executeIfEnabledToggleSwitch = _this.executeIfEnabled(_this.toggleSwitch);
    _this.executeIfEnabledActivateSwitch = _this.executeIfEnabled(_this.activateToggle);
    _this.executeIfEnabledDeactivateSwitch = _this.executeIfEnabled(_this.deactivateToggle);
    return _this;
  }

  (0, _createClass3.default)(AtomSwitch, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('keydown', this.keyBindings, true);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('keydown', this.keyBindings, true);
    }
  }, {
    key: 'render',
    value: function render() {
      var _state = this.state,
          toggle = _state.toggle,
          isFocus = _state.isFocus;


      return this.props.type === TYPES.SINGLE ? _react2.default.createElement(_single.SingleSwitchTypeRender, (0, _extends3.default)({}, this.props, {
        isToggle: toggle,
        isFocus: isFocus,
        focusSwitchCallback: this.executeIfEnabledFocusSwitch,
        blurSwitchCallback: this.executeIfEnabledFocusOutSwitch,
        toggleSwitchCallback: this.executeIfEnabledToggleSwitch
      })) : _react2.default.createElement(_toggle.ToggleSwitchTypeRender, (0, _extends3.default)({}, this.props, {
        isToggle: toggle,
        isFocus: isFocus,
        focusSwitchCallback: this.executeIfEnabledFocusSwitch,
        blurSwitchCallback: this.executeIfEnabledFocusOutSwitch,
        toggleSwitchCallback: this.executeIfEnabledToggleSwitch,
        activateToggleCallback: this.executeIfEnabledActivateSwitch,
        deactivateToggleCallback: this.executeIfEnabledDeactivateSwitch
      }));
    }
  }]);
  return AtomSwitch;
}(_react.Component);

AtomSwitch.displayName = 'AtomSwitch';

AtomSwitch.propTypes = process.env.NODE_ENV !== "production" ? process.env.NODE_ENV !== "production" ? {
  /**
   * Size of switch: 'default', 'large'
   */
  size: _propTypes2.default.oneOf([SIZES.DEFAULT, SIZES.LARGE]),
  /**
   * Type of switch: 'toggle' (default), 'select', 'single'
   */
  type: _propTypes2.default.oneOf([TYPES.TOGGLE, TYPES.SELECT, TYPES.SINGLE]),
  /**
   * Is Input disabled?
   */
  disabled: _propTypes2.default.bool,
  /**
   * Left label to be printed
   */
  labelLeft: _propTypes2.default.string,
  /**
   * Right label to be printed
   */
  labelRight: _propTypes2.default.string,
  /**
   * Form element name
   */
  name: _propTypes2.default.string.isRequired,
  /**
   * The label itself. Proxy from label
   */
  label: _propTypes2.default.string.isRequired,
  /**
   * The optional label text. Proxy from label
   */
  labelOptionalText: _propTypes2.default.string,
  /**
   * Callback to be called when switch. Flag whenever switch is active or not sent
   */
  onToggle: _propTypes2.default.func.isRequired
} : {} : {};

AtomSwitch.defaultProps = {
  size: SIZES.DEFAULT,
  disabled: false,
  labelLeft: 'Off',
  labelRight: 'On',
  type: TYPES.TOGGLE
};

exports.default = AtomSwitch;